@@ -1,35 +1,34 @@
-package Devel::Command::DBSub::DB_5_8_6;
+package Devel::Command::DBSub::DB_5_10;
 
 sub import {
-  # Includes 5.8.6, 5.8.7 and 5.8.8.
-  # Also includes 5.9.2, 5.9.3 and 5.9.4.
-  if( $] gt "5.008005" or 
-      ( $] gt "5.009001" and
-        $] lt "5.009005"
-      ) 
-    ) {
-    return \&DB::alt_586_DB;
-  }
-  else {
-    return;
+  if (my($sub_version) = 
+        # 5.9.5's debugger is based on the 5.10 release.
+        # 5.11 is (so far) based on 5.10 as well.
+        ($] =~ /^5.010(.*)/ or
+         $] =~ /^5.011(.*)/ or 
+         $] =~ /^5.009005/)
+     ) {
+      return \&DB::alt_510_DB;
+    }
+    else {
+      # Not 5.10 or 5.9.5.
+      return undef;
   }
 }
 
 {
 no strict;
 no warnings;
+
 package DB;
 
-sub alt_586_DB {
+sub alt_510_DB {
 
     # lock the debugger and get the thread id for the prompt
 	lock($DBGR);
 	my $tid;
 	if ($ENV{PERL5DB_THREADED}) {
-		$tid = eval { "[".threads->self->tid."]" };
-	}
-	else {
-	        $tid = "";
+		$tid = eval { "[".threads->tid."]" };
 	}
 
     # Check for whether we should be running continuously or not.
@@ -180,7 +179,7 @@ EOP
             print_help(<<EOP);
 Debugged program terminated.  Use B<q> to quit or B<R> to restart,
   use B<o> I<inhibit_exit> to avoid stopping after program termination,
-  B<h q>, B<h R> or B<h O> to get additional info.  
+  B<h q>, B<h R> or B<h o> to get additional info.  
 EOP
 
             # Set the DB::eval context appropriately.
@@ -306,7 +305,7 @@ EOP
           )
         {
 
-			defined \&share and share($cmd);
+			share($cmd);
             # ... try to execute the input as debugger commands.
 
             # Don't stop running.
@@ -357,16 +356,16 @@ EOP
                     }
                 } ## end if ($alias{$i})
 
-### Extended commands
+                ### Extended commands
 
-### Define your extended commands in C<%commands> at the top of the file.
-### This section runs them.
+                ### Define your extended commands in C<%commands> at the top of the file.
+                ### This section runs them.
 
-               foreach my $do (keys %DB::commands) {
+                foreach my $do (keys %DB::commands) {
                  next unless $cmd =~ /^$do\s*/;
                  $commands{$do}->($cmd) and next CMD;
-		 #  ? next CMD : last CMD;
-               }
+                 #  ? next CMD : last CMD;
+                }
 
                 $cmd =~ /^q$/ && do {
                     $fall_off_end = 1;
@@ -425,7 +424,7 @@ EOP
                     @vars     = split( ' ', $2 );
 
                     # If main::dumpvar isn't here, get it.
-                    do 'dumpvar.pl' unless defined &main::dumpvar;
+                    do 'dumpvar.pl' || die $@ unless defined &main::dumpvar;
                     if ( defined &main::dumpvar ) {
 
                         # We got it. Turn off subroutine entry/exit messages
@@ -573,7 +572,7 @@ EOP
                       and next CMD;
 
                     # Load up dumpvar if we don't have it. If we can, that is.
-                    do 'dumpvar.pl' unless defined &main::dumpvar;
+                    do 'dumpvar.pl' || die $@ unless defined &main::dumpvar;
                     defined &main::dumpvar
                       or print $OUT "dumpvar.pl not available.\n"
                       and next CMD;
@@ -626,6 +625,7 @@ EOP
                     last CMD;
                 };
 
+
                 # c - start continuous execution.
                 $cmd =~ /^c\b\s*([\w:]*)\s*$/ && do {
 
@@ -699,7 +699,7 @@ EOP
                     # sure that the line specified really is breakable.
                     #
                     # On the other hand, if there was a subname supplied, the
-                    # preceeding block has moved us to the proper file and
+                    # preceding block has moved us to the proper file and
                     # location within that file, and then scanned forward
                     # looking for the next executable line. We have to make
                     # sure that one was found.
@@ -1220,8 +1220,10 @@ EOP
                 $onetimedumpDepth = undef;
             }
             elsif ( $term_pid == $$ ) {
-                STDOUT->flush();
-                STDERR->flush();
+		eval {		# May run under miniperl, when not available...
+                    STDOUT->flush();
+                    STDERR->flush();
+		};
 
                 # XXX If this is the master pid, print a newline.
                 print $OUT "\n";
@@ -1308,7 +1310,7 @@ __END__
 
 =head1 NAME
 
-Devel::Command::DBSub::DB_5_8_6 - Devel::Command debugger patch for 5.8.6 and up
+Devel::Command::DBSub::DB_5_10 - Devel::Command debugger patch for 5.10
 
 =head1 SYNOPSIS
 
@@ -1317,12 +1319,12 @@ Devel::Command::DBSub::DB_5_8_6 - Devel::Command debugger patch for 5.8.6 and up
 
 =head1 DESCRIPTION
 
-C<Devel::Command::DBSub::DB_5_8_6> loads a patched version of the debugger's
-C<DB()> routine that will work with Perl 5.8.6 and up.
+C<Devel::Command::DBSub::DB_5_10> loads a patched version of the debugger's
+C<DB()> routine that will work with Perl 5.10.
 
-=head2 alt_586_DB
+=head2 alt_510_DB
 
-This subroutine is essentially a copy of the 5.8.6 DB::DB function, with the code
+This subroutine is essentially a copy of the 5.10 DB::DB function, with the code
 necessary to pick up custom functions patched in.
 
 =head1 NOTE
@@ -1349,6 +1351,4 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
-
 =cut
-
